@@ -2,6 +2,7 @@ use crate::common::Region;
 use anyhow::Context;
 use anyhow::Result;
 use bio::io::fasta;
+use itertools::Itertools;
 use serde::Serialize;
 use std::collections::HashMap;
 use std::path::Path;
@@ -26,11 +27,14 @@ pub fn read_fasta<P: AsRef<Path>>(
         ind += 1;
     }
     for a in seq {
+        let base = char::from(a);
+        let marker = base.to_uppercase().collect_vec().pop().unwrap();
         let b = Nucleobase {
             start_position: ind as f64 - 0.5,
             end_position: ind as f64 + 0.5,
-            marker_type: a as char,
+            marker_type: marker,
             row: 0,
+            repeat: base.is_lowercase(),
         };
         fasta.push(b);
         ind += 1;
@@ -54,6 +58,7 @@ pub struct Nucleobase {
     end_position: f64,
     marker_type: char,
     row: u8,
+    repeat: bool,
 }
 
 impl Nucleobase {
